// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package commands

import (
	"github.com/jessevdk/go-flags"
	"gitlab.schukai.com/oss/utilities/documentation-manager/environment"
	"gitlab.schukai.com/oss/utilities/documentation-manager/translations"
	"strings"
)

func Execute(Info environment.InfoStruct) {

	environment.State.SetInfo(Info)

	initTerminalState()
	initCommands()

	_, err := environment.State.ParseArguments()
	checkError(err)

	environment.InitConfiguration(definition.ConfigurationPath)

	a := environment.State.GetParser().Command.Active
	if a == nil {
		environment.ExitWithError(1, "No active command found")
	}

	queue := []string{}
	runCommand(queue, environment.State.GetParser().Command.Active)

}

func initTerminalState() {

	parser := flags.NewParser(definition, flags.Default)

	parser.ShortDescription = translations.T.Sprintf("This program can be used to create documentation for your project.")
	parser.LongDescription = translations.T.Sprintf("This program can be used to create documentation for your project.\nIt can be used to create a new documentation project,\nadd new documentation to an existing project, or to generate\ndocumentation from a source code project.")

	environment.State.SetParser(parser)
	//State.definition = definition

}

func runCommand(queue []string, activeCommand *flags.Command) {

	queue = append(queue, activeCommand.Name)

	if activeCommand.Active != nil {
		runCommand(queue, activeCommand.Active)
		return
	}

	k := strings.Join(queue, "-")

	if handler, ok := environment.Handlers.Executor[k]; ok {
		execute := handler.Execute
		execute(activeCommand)
	} else {
		environment.ExitWithError(1, "handler %s not found", k)
	}
}
