// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package commands

import (
	"github.com/jessevdk/go-flags"
	"gitlab.schukai.com/oss/utilities/documentation-manager/environment"
	"gitlab.schukai.com/oss/utilities/documentation-manager/translations"
)

const documentSymbol = "document"

func init() {

	h := environment.Handler{
		Init: initDocument,
	}

	environment.Handlers.Executor[documentSymbol] = h

}

type DocumentDefinition struct {
	SourcePath string                 `long:"path" short:"p"`
	DateFormat string                 `long:"date-format" short:"d"`
	Add        DocumentAddDefinition  `command:"add" alias:"a"`
	HTML       DocumentHTMLDefinition `command:"html" alias:"h"`
	PDF        DocumentPDFDefinition  `command:"pdf"`
}

func initDocument(command *flags.Command) {
	const text = "Functions for creating and editing documents"
	command.ShortDescription = translations.T.Sprintf(text)
	command.LongDescription = translations.T.Sprintf(text)

	for _, opt := range command.Options() {
		switch opt.LongName {
		case "path":
			opt.Description = translations.T.Sprintf("base directory in which the documents are saved")
		case "date-format":
			opt.Description = translations.T.Sprintf("date format for the creation date")
		}
	}

}
