// Copyright 2023 schukai GmbH
// SPDX-License-Identifier: AGPL-3.0

package commands

import (
	"github.com/jessevdk/go-flags"
	"gitlab.schukai.com/oss/utilities/documentation-manager/document"
	"gitlab.schukai.com/oss/utilities/documentation-manager/environment"
	"gitlab.schukai.com/oss/utilities/documentation-manager/translations"
)

const documentPdfSymbol = "document-pdf"

func init() {

	h := environment.Handler{
		Init:    initDocumentPDF,
		Execute: runDocumentPDF,
	}

	environment.Handlers.Executor[documentPdfSymbol] = h

}

type DocumentPDFDefinition struct {
	LatexTemplate    string `long:"latex-template" short:"l"`
	MarkdownTemplate string `long:"markdown-template" short:"m"`
	OutputPath       string `long:"output" short:"o"`
	Verbose          bool   `long:"verbose" short:"v"`
}

func initDocumentPDF(command *flags.Command) {
	const text = "Build the documentation as PDF"
	command.ShortDescription = translations.T.Sprintf(text)
	command.LongDescription = translations.T.Sprintf(text)

	for _, opt := range command.Options() {
		switch opt.LongName {
		case "latex-template":
			opt.Description = translations.T.Sprintf("latex template for the new document")
		case "markdown-template":
			opt.Description = translations.T.Sprintf("md template for the new document")
		case "output":
			opt.Description = translations.T.Sprintf("filename for the new document")
		case "verbose":
			opt.Description = translations.T.Sprintf("verbose output")
		}
	}

}

func runDocumentPDF(command *flags.Command) {

	env := document.BuildPdfEnvironment{
		DateFormat: environment.State.GetDocumentDateFormat(definition.Document.DateFormat),
		SourcePath: environment.State.GetDocumentPath(definition.Document.SourcePath),
		OutputPath: environment.State.GetDocumentPDFOutputPath(definition.Document.PDF.OutputPath),
	}

	env.Templates.Latex = environment.State.GetPDFLatexTemplatePath(definition.Document.PDF.LatexTemplate)
	env.Templates.Markdown = environment.State.GetPDFMarkdownTemplatePath(definition.Document.PDF.MarkdownTemplate)
	env.Verbose = definition.Document.PDF.Verbose

	document.BuildPDF(env)

	if environment.State.HasErrorsWarningsOrMessages() {
		environment.PrintMessages()
	}

}
